'use strict';

function stripLatin1Accent(c) {
  switch (c) {
    case '\u00C0':
    case '\u00C1':
    case '\u00C2':
    case '\u00C3':
    case '\u00C4':
    case '\u00C5':
    case '\u00E0':
    case '\u00E1':
    case '\u00E2':
    case '\u00E3':
    case '\u00E4':
    case '\u00E5':
    case '\u0100':
    case '\u0101':
    case '\u0102':
    case '\u0103':
    case '\u0104':
    case '\u0105':
      return 'a';

    case '\u00C7':
    case '\u00E7':
    case '\u0106':
    case '\u0107':
    case '\u0108':
    case '\u0109':
    case '\u010A':
    case '\u010B':
    case '\u010C':
    case '\u010D':
      return 'c';

    case '\u00D0':
    case '\u00F0':
    case '\u010E':
    case '\u010F':
    case '\u0110':
    case '\u0111':
      return 'd';

    case '\u00C8':
    case '\u00C9':
    case '\u00CA':
    case '\u00CB':
    case '\u00E8':
    case '\u00E9':
    case '\u00EA':
    case '\u00EB':
    case '\u0112':
    case '\u0113':
    case '\u0114':
    case '\u0115':
    case '\u0116':
    case '\u0117':
    case '\u0118':
    case '\u0119':
    case '\u011A':
    case '\u011B':
      return 'e';

    case '\u011C':
    case '\u011D':
    case '\u011E':
    case '\u011F':
    case '\u0120':
    case '\u0121':
    case '\u0122':
    case '\u0123':
      return 'g';

    case '\u0124':
    case '\u0125':
    case '\u0126':
    case '\u0127':
      return 'h';

    case '\u00CC':
    case '\u00CD':
    case '\u00CE':
    case '\u00CF':
    case '\u00EC':
    case '\u00ED':
    case '\u00EE':
    case '\u00EF':
    case '\u0128':
    case '\u0129':
    case '\u012A':
    case '\u012B':
    case '\u012C':
    case '\u012D':
    case '\u012E':
    case '\u012F':
    case '\u0130':
    case '\u0131':
      return 'i';

    case '\u0134':
    case '\u0135':
      return 'j';

    case '\u0136':
    case '\u0137':
    case '\u0138':
      return 'k';

    case '\u0139':
    case '\u013A':
    case '\u013B':
    case '\u013C':
    case '\u013D':
    case '\u013E':
    case '\u013F':
    case '\u0140':
    case '\u0141':
    case '\u0142':
      return 'l';

    case '\u00D1':
    case '\u00F1':
    case '\u0143':
    case '\u0144':
    case '\u0145':
    case '\u0146':
    case '\u0147':
    case '\u0148':
    case '\u0149':
    case '\u014A':
    case '\u014B':
      return 'n';

    case '\u00D2':
    case '\u00D3':
    case '\u00D4':
    case '\u00D5':
    case '\u00D6':
    case '\u00D8':
    case '\u00F2':
    case '\u00F3':
    case '\u00F4':
    case '\u00F5':
    case '\u00F6':
    case '\u00F8':
    case '\u014C':
    case '\u014D':
    case '\u014E':
    case '\u014F':
    case '\u0150':
    case '\u0151':
      return 'o';

    case '\u0154':
    case '\u0155':
    case '\u0156':
    case '\u0157':
    case '\u0158':
    case '\u0159':
      return 'r';

    case '\u015A':
    case '\u015B':
    case '\u015C':
    case '\u015D':
    case '\u015E':
    case '\u015F':
    case '\u0160':
    case '\u0161':
    case '\u017F':
      return 's';

    case '\u0162':
    case '\u0163':
    case '\u0164':
    case '\u0165':
    case '\u0166':
    case '\u0167':
      return 't';

    case '\u00D9':
    case '\u00DA':
    case '\u00DB':
    case '\u00DC':
    case '\u00F9':
    case '\u00FA':
    case '\u00FB':
    case '\u00FC':
    case '\u0168':
    case '\u0169':
    case '\u016A':
    case '\u016B':
    case '\u016C':
    case '\u016D':
    case '\u016E':
    case '\u016F':
    case '\u0170':
    case '\u0171':
    case '\u0172':
    case '\u0173':
      return 'u';

    case '\u0174':
    case '\u0175':
      return 'w';

    case '\u00DD':
    case '\u00FD':
    case '\u00FF':
    case '\u0176':
    case '\u0177':
    case '\u0178':
      return 'y';

    case '\u0179':
    case '\u017A':
    case '\u017B':
    case '\u017C':
    case '\u017D':
    case '\u017E':
      return 'z';

    default:
      return c;
  }
}

const NonAscii = /[\u0080-\uffff]/g; // Punctuation regex built using http://www.unicode.org/Public/UNIDATA/UnicodeData.txt

const PunctuationControl = /(?:[\0-\x08\n-\x1F\x7F]|[!-#%-\*,-\/:;\?@\[-\]_\{\}\xA1\xA7\xAB\xB6\xB7\xBB\xBF\u037E\u0387\u055A-\u055F\u0589\u058A\u05BE\u05C0\u05C3\u05C6\u05F3\u05F4\u0609\u060A\u060C\u060D\u061B\u061E\u061F\u066A-\u066D\u06D4\u0700-\u070D\u07F7-\u07F9\u0830-\u083E\u085E\u0964\u0965\u0970\u09FD\u0A76\u0AF0\u0C84\u0DF4\u0E4F\u0E5A\u0E5B\u0F04-\u0F12\u0F14\u0F3A-\u0F3D\u0F85\u0FD0-\u0FD4\u0FD9\u0FDA\u104A-\u104F\u10FB\u1360-\u1368\u1400\u166D\u166E\u169B\u169C\u16EB-\u16ED\u1735\u1736\u17D4-\u17D6\u17D8-\u17DA\u1800-\u180A\u1944\u1945\u1A1E\u1A1F\u1AA0-\u1AA6\u1AA8-\u1AAD\u1B5A-\u1B60\u1BFC-\u1BFF\u1C3B-\u1C3F\u1C7E\u1C7F\u1CC0-\u1CC7\u1CD3\u2010-\u2027\u2030-\u2043\u2045-\u2051\u2053-\u205E\u207D\u207E\u208D\u208E\u2308-\u230B\u2329\u232A\u2768-\u2775\u27C5\u27C6\u27E6-\u27EF\u2983-\u2998\u29D8-\u29DB\u29FC\u29FD\u2CF9-\u2CFC\u2CFE\u2CFF\u2D70\u2E00-\u2E2E\u2E30-\u2E4E\u3001-\u3003\u3008-\u3011\u3014-\u301F\u3030\u303D\u30A0\u30FB\uA4FE\uA4FF\uA60D-\uA60F\uA673\uA67E\uA6F2-\uA6F7\uA874-\uA877\uA8CE\uA8CF\uA8F8-\uA8FA\uA8FC\uA92E\uA92F\uA95F\uA9C1-\uA9CD\uA9DE\uA9DF\uAA5C-\uAA5F\uAADE\uAADF\uAAF0\uAAF1\uABEB\uFD3E\uFD3F\uFE10-\uFE19\uFE30-\uFE52\uFE54-\uFE61\uFE63\uFE68\uFE6A\uFE6B\uFF01-\uFF03\uFF05-\uFF0A\uFF0C-\uFF0F\uFF1A\uFF1B\uFF1F\uFF20\uFF3B-\uFF3D\uFF3F\uFF5B\uFF5D\uFF5F-\uFF65\u{10100}-\u{10102}\u{1039F}\u{103D0}\u{1056F}\u{10857}\u{1091F}\u{1093F}\u{10A50}-\u{10A58}\u{10A7F}\u{10AF0}-\u{10AF6}\u{10B39}-\u{10B3F}\u{10B99}-\u{10B9C}\u{10F55}-\u{10F59}\u{11047}-\u{1104D}\u{110BB}\u{110BC}\u{110BE}-\u{110C1}\u{11140}-\u{11143}\u{11174}\u{11175}\u{111C5}-\u{111C8}\u{111CD}\u{111DB}\u{111DD}-\u{111DF}\u{11238}-\u{1123D}\u{112A9}\u{1144B}-\u{1144F}\u{1145B}\u{1145D}\u{114C6}\u{115C1}-\u{115D7}\u{11641}-\u{11643}\u{11660}-\u{1166C}\u{1173C}-\u{1173E}\u{1183B}\u{11A3F}-\u{11A46}\u{11A9A}-\u{11A9C}\u{11A9E}-\u{11AA2}\u{11C41}-\u{11C45}\u{11C70}\u{11C71}\u{11EF7}\u{11EF8}\u{12470}-\u{12474}\u{16A6E}\u{16A6F}\u{16AF5}\u{16B37}-\u{16B3B}\u{16B44}\u{16E97}-\u{16E9A}\u{1BC9F}\u{1DA87}-\u{1DA8B}\u{1E95E}\u{1E95F}])+/ug; // by the time we're searching for whitespace we've already nixed control chars

const Whitespace = /[\x00-\x20]+/g;

function doFingerprint(s) {
  s = s.trim();
  s = s.toLowerCase();
  s = s.replace(NonAscii, stripLatin1Accent);
  s = s.replace(PunctuationControl, '');
  const tokens = s.split(Whitespace);
  tokens.sort();
  const uniqueTokens = [];
  let lastToken = null;
  const nTokens = tokens.length;

  for (let i = 0; i < nTokens; i++) {
    const token = tokens[i];

    if (token !== lastToken) {
      uniqueTokens.push(token);
      lastToken = token;
    }
  }

  return uniqueTokens.join(' ');
}

function fingerprint() {
  return doFingerprint;
}

module.exports = fingerprint;
//# sourceMappingURL=fingerprint.js.map
